################
Config platforms
################

The platforms page of the config tab allows you to set platforms you want to download ROMs for. The order here just
determines the order each platform is processed.

.. image:: ../images/config_platforms.png
